==> qtjambi-remoteobjects-jre8-5.15.3-sources.jar: io/qt/remoteobjects/QRemoteObjectAbstractPersistedStore.java <==
package io.qt.remoteobjects;


/**
 * <p>A class which provides the methods for setting PROP values of a replica to value they had the last time the replica was used</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html">QRemoteObjectAbstractPersistedStore</a></p>
 */
public abstract class QRemoteObjectAbstractPersistedStore extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectAbstractPersistedStore.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QRemoteObjectAbstractPersistedStore {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public java.util.List<java.lang.Object> restoreProperties(java.lang.String repName, io.qt.core.QByteArray repSig){
            return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
        }
        @io.qt.QtUninvokable
        private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
        
        
        @Override
        @io.qt.QtUninvokable
        public void saveProperties(java.lang.String repName, io.qt.core.QByteArray repSig, java.util.Collection<java.lang.Object> values){
            saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
        }
        @io.qt.QtUninvokable
        private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<java.lang.Object> values);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectAbstractPersistedStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectAbstractPersistedStore() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#QRemoteObjectAbstractPersistedStore">QRemoteObjectAbstractPersistedStore::QRemoteObjectAbstractPersistedStore(QObject*)</a></p>
     */
    public QRemoteObjectAbstractPersistedStore(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectAbstractPersistedStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#restoreProperties">QRemoteObjectAbstractPersistedStore::restoreProperties(QString,QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.util.List<java.lang.Object> restoreProperties(java.lang.String repName, io.qt.core.QByteArray repSig);
    
    @io.qt.QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qremoteobjectabstractpersistedstore.html#saveProperties">QRemoteObjectAbstractPersistedStore::saveProperties(QString,QByteArray,QVariantList)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void saveProperties(java.lang.String repName, io.qt.core.QByteArray repSig, java.util.Collection<java.lang.Object> values);
    
    @io.qt.QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRemoteObjectAbstractPersistedStore instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-jre8-6.2.1-sources.jar: io/qt/remoteobjects/QRemoteObjectAbstractPersistedStore.java <==
package io.qt.remoteobjects;


/**
 * <p>A class which provides the methods for setting PROP values of a replica to value they had the last time the replica was used</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qremoteobjectabstractpersistedstore.html">QRemoteObjectAbstractPersistedStore</a></p>
 */
public abstract class QRemoteObjectAbstractPersistedStore extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectAbstractPersistedStore.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QRemoteObjectAbstractPersistedStore {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public java.util.List<java.lang.Object> restoreProperties(java.lang.String repName, io.qt.core.QByteArray repSig){
            return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
        }
        @io.qt.QtUninvokable
        private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
        
        
        @Override
        @io.qt.QtUninvokable
        public void saveProperties(java.lang.String repName, io.qt.core.QByteArray repSig, java.util.Collection<java.lang.Object> values){
            saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
        }
        @io.qt.QtUninvokable
        private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<java.lang.Object> values);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectAbstractPersistedStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectAbstractPersistedStore() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectabstractpersistedstore.html#QRemoteObjectAbstractPersistedStore">QRemoteObjectAbstractPersistedStore::QRemoteObjectAbstractPersistedStore(QObject*)</a></p>
     */
    public QRemoteObjectAbstractPersistedStore(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectAbstractPersistedStore instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectabstractpersistedstore.html#restoreProperties">QRemoteObjectAbstractPersistedStore::restoreProperties(QString,QByteArray)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.util.List<java.lang.Object> restoreProperties(java.lang.String repName, io.qt.core.QByteArray repSig);
    
    @io.qt.QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qremoteobjectabstractpersistedstore.html#saveProperties">QRemoteObjectAbstractPersistedStore::saveProperties(QString,QByteArray,QVariantList)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void saveProperties(java.lang.String repName, io.qt.core.QByteArray repSig, java.util.Collection<java.lang.Object> values);
    
    @io.qt.QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectAbstractPersistedStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRemoteObjectAbstractPersistedStore instance, QDeclarativeConstructor constructor);
    
}
